@@ -1,6 +1,6 @@
 package App::ansicolumn;
 
-our $VERSION = "1.36";
+our $VERSION = "1.37";
 
 use v5.14;
 use warnings;
@@ -24,7 +24,7 @@ use Getopt::EX::RPN qw(rpn_calc);
 my %DEFAULT_COLORMAP = (
     BORDER => '',
     TEXT   => '',
-    );
+);
 
 use Getopt::EX::Hashed 1.05; {
 
@@ -276,27 +276,22 @@ sub parallel_out {
     $obj->pane ||= @files;
     $obj->set_horizontal($max_line_length);
 
-    # calculate span and set for each files
-    if ($obj->cell) {
-	my @spans = do {
-	    map {
-		if (/^[-+]/) {
-		    $obj->{span} + $_;
-		} else {
-		    $_;
-		}
-	    }
-	    split /,+/, $obj->cell;
-	};
+    # calculate span and set for each file
+    if (my $cell = $obj->cell) {
+	my @spans = split /,+/, $cell;
 	for my $i (keys @files) {
 	    my $span = $spans[$i] // $spans[-1];
 	    if ($span =~ /^[-+]/) {
 		$span += $obj->{span};
+		$span < 0 and die "Invalid number: $cell\n";
 	    }
-	    elsif ($span =~ s/^(<=|[=<])//) {
+	    elsif ($span =~ s/^(<=|[<=])//) {
 		my $length = $files[$i]->{length};
 		$span = $span ? min($length, $span) : $length;
 	    }
+	    else {
+		die "Invalid number: $cell\n";
+	    }
 	    $files[$i]->{span} = $span;
 	}
     }
